@@ -20,6 +20,7 @@ from .timm_sknet import timm_sknet_encoders
 from .timm_mobilenetv3 import timm_mobilenetv3_encoders
 from .timm_gernet import timm_gernet_encoders
 from .mix_transformer import mix_transformer_encoders
+from .mobileone import mobileone_encoders
 
 from .timm_universal import TimmUniversalEncoder
 
@@ -44,6 +45,7 @@ encoders.update(timm_sknet_encoders)
 encoders.update(timm_mobilenetv3_encoders)
 encoders.update(timm_gernet_encoders)
 encoders.update(mix_transformer_encoders)
+encoders.update(mobileone_encoders)
 
 
 def get_encoder(name, in_channels=3, depth=5, weights=None, output_stride=32, **kwargs):
@@ -97,9 +99,9 @@ def get_preprocessing_params(encoder_name, pretrained="imagenet"):
 
     if encoder_name.startswith("tu-"):
         encoder_name = encoder_name[3:]
-        if encoder_name not in timm.models.registry._model_has_pretrained:
+        if not timm.models.is_model_pretrained(encoder_name):
             raise ValueError(f"{encoder_name} does not have pretrained weights and preprocessing parameters")
-        settings = timm.models.registry._model_default_cfgs[encoder_name]
+        settings = timm.models.get_pretrained_cfg(encoder_name)
     else:
         all_settings = encoders[encoder_name]["pretrained_settings"]
         if pretrained not in all_settings.keys():
