@@ -73,7 +73,7 @@ timm_sknet_encoders = {
             "out_channels": (3, 64, 64, 128, 256, 512),
             "block": SelectiveKernelBasic,
             "layers": [2, 2, 2, 2],
-            "zero_init_last_bn": False,
+            "zero_init_last": False,
             "block_args": {"sk_kwargs": {"rd_ratio": 1 / 8, "split_input": True}},
         },
     },
@@ -84,7 +84,7 @@ timm_sknet_encoders = {
             "out_channels": (3, 64, 64, 128, 256, 512),
             "block": SelectiveKernelBasic,
             "layers": [3, 4, 6, 3],
-            "zero_init_last_bn": False,
+            "zero_init_last": False,
             "block_args": {"sk_kwargs": {"rd_ratio": 1 / 8, "split_input": True}},
         },
     },
@@ -95,7 +95,7 @@ timm_sknet_encoders = {
             "out_channels": (3, 64, 256, 512, 1024, 2048),
             "block": SelectiveKernelBottleneck,
             "layers": [3, 4, 6, 3],
-            "zero_init_last_bn": False,
+            "zero_init_last": False,
             "cardinality": 32,
             "base_width": 4,
         },
